<?php
/**
 * Widget Class.
 *
 * @since 1.0.0
 */
use \Elementor\Core\Kits\Documents\Tabs\Global_Typography;
class xaddons_button_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'xa-button';
	}

	
	public function get_title() {
		return __( 'XA: Button', 'x-addons-elementor' );
	}

	public function get_keywords() {
		return [ 'xaddons', 'btn', 'dualbutton', 'buttons' ];
	}
	
	public function get_categories() {
		return [ 'x-addons' ];
	}

	protected function register_controls() {

		$this->register_content_controls();
        $this->register_style_controls();
	}


	/* Register Control*/
	protected function register_content_controls() {
		

		// Tab #1
		$this->start_controls_section(
			'xaddons_tab_basic',
			[
				'label' => __( 'Button Styles', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
            'xaddons_show_2nd_button',
            [
                'label' => __('Show Second Button?', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'x-addons-elementor'),
                'label_off' => __('No', 'x-addons-elementor'),
                'default' => '',
            ]
        );

		$this->add_control(
            'xaddons_button_mlabel',
            [
                'label' => __('Button Middle Label?', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'x-addons-elementor'),
                'label_off' => __('No', 'x-addons-elementor'),
                'default' => 'yes',
				'condition' => [
                    'xaddons_show_2nd_button' => 'yes',
                ],    
            ]
        );

		$this->add_control(
			'xaddons_button_mlabel_text',
			[
				'label' => __( 'Button Middle Label', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'OR',
				'placeholder' => __('OR', 'x-addons-elementor'),
				'label_block' => true,
				'condition' => [
                    'xaddons_show_2nd_button' => 'yes',
                    'xaddons_button_mlabel' => 'yes',
                ],    
			]
		);


		$this->end_controls_section();
		
		// Tab #1
		$this->start_controls_section(
			'xaddons_tab_one',
			[
				'label' => __( 'Button Default', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'xaddons_button_text',
			[
				'label' => __( 'Button Text', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'About Us',
				'placeholder' => __('About Us', 'x-addons-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'xaddons_button_link',
			[
				'label' => __( 'Button Link', 'x-addons-elementor' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [ 'url' => '#',],
				'placeholder' => __('https://example-site.com', 'x-addons-elementor'),
			]
		);

		$this->add_control(
            'xaddons_use_icon',
            [
                'label' => __('Use Icon?', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'x-addons-elementor'),
                'label_off' => __('No', 'x-addons-elementor'),
                'default' => 'yes',
            ]
        );

		$this->add_control(
			'xaddons_button_icon',
			[
				'label' => esc_html__( 'Button Icon', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::ICONS,      
				'default' => [
					'value' => 'fas fa-arrow-right',
					'library' => 'solid',
				],
				'separator' => 'before',     
				'condition' => [
					'xaddons_use_icon' => 'yes',
				],
			]
		);

		$this->add_control(
			'xaddons_button_dir',
			[
				'label' => esc_html__( 'Icon Position', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'default' => 'style-2',
				'options' => [
					'style-1' => [
                        'title' => __('Before Text', 'x-addons-elementor'),
                        'icon' => 'fas fa-arrow-left',
                    ],
                    'style-2' => [
                        'title' => __('After Text', 'x-addons-elementor'),
                        'icon' => 'fas fa-arrow-right',
                    ],
				],      
				'condition' => [
					'xaddons_use_icon' => 'yes',
				],
			]
		);

		$this->end_controls_section();

		// Tab #2
		$this->start_controls_section(
			'xaddons_tab_two',
			[
				'label' => __( 'Second Button', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
                    'xaddons_show_2nd_button' => 'yes',
                ],     
			]
		);

		$this->add_control(
			'xaddons_button_text2',
			[
				'label' => __( 'Button Text', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Our Services',
				'placeholder' => __('Our Services', 'x-addons-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'xaddons_button_link2',
			[
				'label' => __( 'Button Link', 'x-addons-elementor' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [ 'url' => '#',],
				'placeholder' => __('https://example-site.com', 'x-addons-elementor'),
			]
		);

		$this->add_control(
            'xaddons_use_icon2',
            [
                'label' => __('Use Icon?', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'x-addons-elementor'),
                'label_off' => __('No', 'x-addons-elementor'),
                'default' => 'yes',
            ]
        );

		$this->add_control(
			'xaddons_button_icon2',
			[
				'label' => esc_html__( 'Button Icon', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::ICONS,      
				'default' => [
					'value' => 'fas fa-arrow-right',
					'library' => 'solid',
				],
				'separator' => 'before',     
				'condition' => [
					'xaddons_use_icon2' => 'yes',
				],
			]
		);

		$this->add_control(
			'xaddons_button_dir2',
			[
				'label' => esc_html__( 'Icon Position', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'default' => 'style-2',
				'options' => [
					'style-1' => [
                        'title' => __('Before Text', 'x-addons-elementor'),
                        'icon' => 'fas fa-arrow-left',
                    ],
                    'style-2' => [
                        'title' => __('After Text', 'x-addons-elementor'),
                        'icon' => 'fas fa-arrow-right',
                    ],
				],      
				'condition' => [
					'xaddons_use_icon2' => 'yes',
				],
			]
		);

		$this->end_controls_section();

		// Tab #2
		$this->start_controls_section(
			'xaddons_tab_three',
			[
				'label' => __( 'Button Styles', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_responsive_control(
            'xaddons_align',
            [
                'label' => __('Button Alignment', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => __('Left', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'flex-end' => [
                        'title' => __('Right', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],

                ],
                'default' => 'flex-start',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .xa-alignment' => 'justify-content: {{VALUE}}; display:flex;',
                ],
            ]
        );
		

		$this->end_controls_section();

	}

	function register_style_controls(){
		
		$this->start_controls_section(
            'xaddons_button_mlabel_style',
            [
                'label' => __('Button Middle Label Style', 'xaddons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
                    'xaddons_button_mlabel' => 'yes',
                    'xaddons_show_2nd_button' => 'yes',
                ],    
            ]
        );

		$this->add_responsive_control(
            'xaddons_button_mlabel_width',
            [
                'label' => esc_html__('Width', 'x-addons-elementor'),
                'type' =>  \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ]
                ],

                'default' => [
                    'unit' => 'px',
                    'size' => 30,
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons .xa-buttons__middle' => 'width: {{SIZE}}{{UNIT}};',

                ],
            ]
        );

		$this->add_responsive_control(
            'xaddons_button_mlabel_height',
            [
                'label' => esc_html__('Height', 'x-addons-elementor'),
                'type' =>  \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ]
                ],

                'default' => [
                    'unit' => 'px',
                    'size' => 30,
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons .xa-buttons__middle' => 'height: {{SIZE}}{{UNIT}};',

                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_button_border',
                'selector' => '{{WRAPPER}} .xa-buttons .xa-buttons__middle'

            ]
        );

		$this->add_responsive_control(
            'xaddons_button_mlabel_radius',
            [
                'label' => __('Border Radius', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons .xa-buttons__middle' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_button_mlabel_shadow',
                'exclude' => [
                    'box_shadow_position',
                ],
                'selector' => '{{WRAPPER}} .xa-buttons .xa-buttons__middle'
            ]
        );

        $this->add_control(
            'xaddons_button_mlabel_color',
            [
                'label' => __('Color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons .xa-buttons__middle' => 'color: {{VALUE}};',
                ],

            ]
        );

		$this->add_control(
            'xaddons_button_mlabel_bg_color',
            [
                'label' => __('Background Color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons .xa-buttons__middle' => 'background-color: {{VALUE}};',
                ],

            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
            'xaddons_button_default_style',
            [
                'label' => __('Default Button style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_responsive_control(
            'xaddons_default_button_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
            'xaddons_default_button_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
            'xaddons_default_button_icon_size',
            [
                'label' => __('Icon Size', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1 i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1 svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
               'condition' => [
					'xaddons_use_icon' => 'yes',
				],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_default_button_border',
                'selector' => '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1',
            ]
        );

		$this->add_control(
            'xaddons_default_button_border_radius',
            [
                'label' => __('Border Radius', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_default_button_shadow',
                'selector' => '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1',
            ]
        );


		$this->add_control(
            'xaddons_default_button_colors',
            [
                'label' => __('Button color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs('xaddons_default_button_tabs');

			$this->start_controls_tab(
				'xaddons_default_button_style',
				[
					'label' => __('Normal', 'xaddons-elementor'),
				]
			);

			$this->add_control(
				'xaddons_default_button_color',
				[
					'label' => __('Text Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1 i' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1 svg' => 'fill: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'xaddons_default_button_bg_color',
				[
					'label' => __('Background Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'xaddons_default_button_hover_style',
				[
					'label' => __('Hover', 'xaddons-elementor'),
				]
			);

			$this->add_control(
				'xaddons_default_button_hover_color',
				[
					'label' => __('Text Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1:hover' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1:hover i' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1:hover svg' => 'fill: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'xaddons_default_button_hover_bg_color',
				[
					'label' => __('Background Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1:hover' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();
		
        $this->end_controls_tabs();
		
        $this->end_controls_section();
		

		$this->start_controls_section(
            'xaddons_2nd_button_style',
            [
                'label' => __('Second Button style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
                    'xaddons_show_2nd_button' => 'yes',
                ],   
            ]
        );

		$this->add_responsive_control(
            'xaddons_2nd_button_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
            'xaddons_2nd_button_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
            'xaddons_2nd_button_icon_size',
            [
                'label' => __('Icon Size', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2 i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2 svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
               'condition' => [
					'xaddons_use_icon' => 'yes',
				],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_2nd_button_border',
                'selector' => '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1',
            ]
        );

		$this->add_control(
            'xaddons_2nd_button_border_radius',
            [
                'label' => __('Border Radius', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_2nd_button_shadow',
                'selector' => '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2',
            ]
        );


		$this->add_control(
            'xaddons_2nd_button_colors',
            [
                'label' => __('Button color 2', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs('xaddons_2nd_button_tabs');

			$this->start_controls_tab(
				'xaddons_2nd_button_tab_style',
				[
					'label' => __('Normal', 'xaddons-elementor'),
				]
			);

			$this->add_control(
				'xaddons_2nd_button_color',
				[
					'label' => __('Text Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2 i' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2 svg' => 'fill: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'xaddons_2nd_button_bg_color',
				[
					'label' => __('Background Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2' => 'background-color: {{VALUE}};',
					],
				]
			);

        	$this->end_controls_tab();

			$this->start_controls_tab(
				'xaddons_2nd_button_hover_style',
				[
					'label' => __('Hover', 'xaddons-elementor'),
				]
			);

			$this->add_control(
				'xaddons_2nd_button_hover_color',
				[
					'label' => __('Text Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2:hover' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2:hover i' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2:hover svg' => 'fill: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'xaddons_2nd_button_hover_bg_color',
				[
					'label' => __('Background Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2:hover' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();
		
        $this->end_controls_tabs();
		
        $this->end_controls_section();

		$this->start_controls_section(
            'xaddons_typography_style',
            [
                'label' => __('Typography style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_button_label_typography',
                'label' => __('Button Middle Label Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-buttons__middle',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_default_button_typography',
                'label' => __('Button Default Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type1',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_2nd_button_typography',
                'label' => __('Second Button Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-buttons__btn.xa-buttons__btn-type2',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->end_controls_section();


	}

	/**
	 * Render  widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	 
	 protected function render() {
		$settings = $this->get_settings_for_display();
	
		// Determine target for link
		$xaddons_target = ( isset($settings['xaddons_button_link']['is_external']) && $settings['xaddons_button_link']['is_external'] === true ) ? '_blank' : '_self';
		$xaddons_target2 = ( isset($settings['xaddons_button_link2']['is_external']) && $settings['xaddons_button_link2']['is_external'] === true ) ? '_blank' : '_self';
		
		if($settings['xaddons_show_2nd_button'] == 'yes'){
			$xa_2nd_button = 'xa-buttons__2nd';
		}else{
			$xa_2nd_button = 'xa-buttons__default';
		}

		echo '
		<div class="xa-wrapper xa-alignment">
			<div class="xa-buttons '.$xa_2nd_button.' ">
				
				<!-- Button One -->
				<a class="xa-buttons__btn xa-buttons__btn-type1" href="' . esc_url( $settings['xaddons_button_link']['url'] ) . '" target="' . esc_attr( $xaddons_target ) . '">
					<div class="xa-buttons__inside">';
					if ( $settings['xaddons_button_dir'] == 'style-1' && $settings['xaddons_use_icon'] == 'yes' ) {
						echo '<span><i class="' . esc_attr( $settings['xaddons_button_icon']['value'] ) . '"></i></span>';
					}
					echo '<span>' . esc_html( $settings['xaddons_button_text'] ) . '</span>';
					if ( $settings['xaddons_button_dir'] == 'style-2'  && $settings['xaddons_use_icon'] == 'yes') {
						echo '<span><i class="' . esc_attr( $settings['xaddons_button_icon']['value'] ) . '"></i></span>';
					}
					echo '
					</div>
				</a>';
				
				if($settings['xaddons_show_2nd_button'] == 'yes'){
					if($settings['xaddons_button_mlabel'] == 'yes'){
					echo'<span class="xa-buttons__middle">' . esc_html( $settings['xaddons_button_mlabel_text'] ) . '</span>';
					}echo'
					<!-- Button Two -->
					<a class="xa-buttons__btn  xa-buttons__btn-type2 xa-buttons__btn--v2" href="' . esc_url( $settings['xaddons_button_link2']['url'] ) . '" target="' . esc_attr( $xaddons_target2 ) . '">
						<div class="xa-buttons__inside">';
		
						if ( $settings['xaddons_button_dir2'] == 'style-1'  && $settings['xaddons_use_icon'] == 'yes') {
							echo '<span><i class="' . esc_attr( $settings['xaddons_button_icon2']['value'] ) . '"></i></span>';
						}
					
						echo '<span>' . esc_html( $settings['xaddons_button_text2'] ) . '</span>';
					
						if ( $settings['xaddons_button_dir2'] == 'style-2'  && $settings['xaddons_use_icon'] == 'yes') {
							echo '<span><i class="' . esc_attr( $settings['xaddons_button_icon2']['value'] ) . '"></i></span>';
						}
					
						echo '
						</div>
					</a>
					
					';
				}echo'


			</div>
		</div>';
	}
	
	 
}