<?php
/**
 * Widget Class.
 *
 * @since 1.0.0
*/

use \Elementor\Core\Kits\Documents\Tabs\Global_Typography;
class xaddons_cta_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return 'xa-cta-widget';
	}

	public function get_title() {
		return __( 'XA: Call to Action', 'x-addons-elementor' );
	}

	public function get_icon() {
		return 'eicon-featured-image';
	}

	public function get_keywords() {
		return [ 'xaddons', 'cta', 'calltoaction', 'banner', 'card'];
	}

	public function get_categories() {
		return [ 'x-addons' ];
	}

	protected function register_controls() {

		$this->register_content_controls();
        $this->register_style_controls();
	}


	protected function register_content_controls() {

		$this->start_controls_section(
			'xaddons_tab_content',
			[
				'label' => __( 'XA CTA Content', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'xaddons_default_bg',
                'label' => esc_html__('Background', 'xaddons-elementor'),
                'types' => ['classic', 'gradient', 'video'],
                'selector' => '{{WRAPPER}} .xa-cta-area',
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

		$this->add_control(
			'xaddons_title',
			[
				'label' => __( 'CTA Title', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'Have any project in your mind?',
				'label_block' => true,

			]
		);

		$this->add_control(
			'xaddons_focus_title',
			[
				'label' => __( 'CTA Focus Title', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Let\'s talk now.',
				'label_block' => true,

			]
		);

		$this->add_control(
			'xaddons_desc',
			[
				'label' => __( 'CTA Description', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'It is a long established fact that a reader will be distracted by the readable content',
				'label_block' => true,

			]
		);

		$this->add_control(
			'xaddons_button_text',
			[

				'label' => __( 'CTA Button Text', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'About Us',
				'label_block' => true,
			]

		);

		$this->add_control(
			'xaddons_button_link',
			[
				'label' => __( 'CTA Button URL', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::URL,
				'label_block' => true,
				'placeholder' => __('https://example-site.com', 'x-addons-elementor'),
			]
		);

		$this->add_control(
            'xaddons_use_icon',
            [
                'label' => __('Use Icon?', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'x-addons-elementor'),
                'label_off' => __('No', 'x-addons-elementor'),
                'default' => 'yes',
            ]
        );

		$this->add_control(
			'xaddons_button_icon',
			[
				'label' => esc_html__( 'Button Icon', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::ICONS,      
				'default' => [
					'value' => 'fas fa-arrow-right',
					'library' => 'solid',
				],
				'separator' => 'before',     
				'condition' => [
					'xaddons_use_icon' => 'yes',
				],
			]
		);

		$this->add_control(
			'xaddons_button_dir',
			[
				'label' => esc_html__( 'Icon Position', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'default' => 'style-2',
				'options' => [
					'style-1' => [
                        'title' => __('Before Text', 'x-addons-elementor'),
                        'icon' => 'fas fa-arrow-left',
                    ],
                    'style-2' => [
                        'title' => __('After Text', 'x-addons-elementor'),
                        'icon' => 'fas fa-arrow-right',
                    ],
				],      
				'condition' => [
					'xaddons_use_icon' => 'yes',
				],
			]
		);

		$this->end_controls_section();
		

	}

	function register_style_controls(){

		$this->start_controls_section(
            'xaddons_default_style',
            [
                'label' => __('Basic Style', 'xaddons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'xaddons_default_padding',
            [
                'label' => __('Padding', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_default_margin',
            [
                'label' => __('Margin', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_default_border',
                'selector' => '{{WRAPPER}} .xa-cta-area'

            ]
        );

        $this->add_responsive_control(
            'xaddons_default_border_radius',
            [
                'label' => __('Border Radius', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .xa-cta-area .xa-overlay' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_default_shadow',
                'exclude' => [
                    'box_shadow_position',
                ],
                'selector' => '{{WRAPPER}} .xa-cta-area'
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
            'xaddons_bg_overlay_style',
            [
                'label' => __('Background Overlay Style', 'xaddons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'xaddons_bg_overlay',
                'selector' => '{{WRAPPER}} .xa-overlay',
            ]
        );

        $this->add_control(
            'xaddons_bg_overlay_opacity',
            [
                'label' => __('Opacity', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'default' => [
                    'size' => .5,
                ],
                'range' => [
                    'px' => [
                        'max' => 1,
                        'step' => 0.01,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-overlay' => 'opacity: {{SIZE}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Css_Filter::get_type(),
            [
                'name' => 'xaddons_bg_overlay_filters',
                'selector' => '{{WRAPPER}} .xa-overlay',
            ]
        );

        $this->end_controls_section();


		$this->start_controls_section(
            'xaddons_title_style',
            [
                'label' => __('Title style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_control(
            'xaddons_title_default_style',
            [
                'type' => \Elementor\Controls_Manager::HEADING,
                'label' => __('Title Style', 'x-addons-elementor'),
                'separator' => 'after'
            ]
        );

		$this->add_responsive_control(
            'xaddons_title_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_title_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-cta-area__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__title' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_background',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__title' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_title_border',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_control(
            'xaddons_title_focus_style',
            [
                'type' => \Elementor\Controls_Manager::HEADING,
                'label' => __('Title Focus Style', 'x-addons-elementor'),
                'separator' => 'before'
            ]
        );

		$this->add_responsive_control(
            'xaddons_title_focus_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__title span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_title_focus_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-cta-area__title span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_focus_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__title span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_focus_background',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__title span' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_title_focus_border',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__title span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


		$this->end_controls_section();

		$this->start_controls_section(
            'xaddons_desc_style',
            [
                'label' => __('Description style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );


		$this->add_responsive_control(
            'xaddons_desc_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_desc_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-cta-area__text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_desc_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_desc_bg',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__text' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_desc_radius',
            [
                'label' => __('Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-cta-area__text' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();


		$this->start_controls_section(
            'xaddons_button_default_style',
            [
                'label' => __('Default Button style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_responsive_control(
            'xaddons_default_button_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
            'xaddons_default_button_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
            'xaddons_default_button_icon_size',
            [
                'label' => __('Icon Size', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .xa-buttons__btn svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
               'condition' => [
					'xaddons_use_icon' => 'yes',
				],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_default_button_border',
                'selector' => '{{WRAPPER}} .xa-buttons__btn',
            ]
        );

		$this->add_control(
            'xaddons_default_button_border_radius',
            [
                'label' => __('Border Radius', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_default_button_shadow',
                'selector' => '{{WRAPPER}} .xa-buttons__btn',
            ]
        );


		$this->add_control(
            'xaddons_default_button_colors',
            [
                'label' => __('Button color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs('xaddons_default_button_tabs');

			$this->start_controls_tab(
				'xaddons_default_button_style',
				[
					'label' => __('Normal', 'xaddons-elementor'),
				]
			);

			$this->add_control(
				'xaddons_default_button_color',
				[
					'label' => __('Text Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn i' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn svg' => 'fill: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'xaddons_default_button_bg_color',
				[
					'label' => __('Background Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'xaddons_default_button_hover_style',
				[
					'label' => __('Hover', 'xaddons-elementor'),
				]
			);

			$this->add_control(
				'xaddons_default_button_hover_color',
				[
					'label' => __('Text Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn:hover' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn:hover i' => 'color: {{VALUE}};',
						'{{WRAPPER}} .xa-buttons__btn:hover svg' => 'fill: {{VALUE}};',

					],
					
				]
			);

			$this->add_control(
				'xaddons_default_button_hover_bg_color',
				[
					'label' => __('Background Color', 'xaddons-elementor'),
					'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
						'{{WRAPPER}} .xa-buttons__btn:hover' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();
		
        $this->end_controls_tabs();
		
        $this->end_controls_section();


		$this->start_controls_section(
            'xaddons_typography_style',
            [
                'label' => __('Typography style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_title_typography',
                'label' => __('Title Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-cta-area__title',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_title_focus_typography',
                'label' => __('Title Focus Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-cta-area__title span',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_desc_typography',
                'label' => __('Content Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-cta-area__text',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_button_text_typography',
                'label' => __('Button Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-buttons__btn',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );


		$this->end_controls_section();


	}


	/**
	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */

	protected function render() {

        $settings = $this->get_settings_for_display();
		
		$xaddons_target = ( $settings['xaddons_button_link']['is_external'] == true ) ? '_blank' : '_self';


        echo '
		<div class="xa-wrapper xa-cta-area xa-overlay-active">
			<div class="xa-overlay"></div>
			<div class="xa-cta-area__content">
				<h2 class="xa-cta-area__title">'.wp_kses_post($settings['xaddons_title']).' <span>'.wp_kses_post($settings['xaddons_focus_title']).'</span> </h2>
				<p class="xa-cta-area__text">'.esc_html($settings['xaddons_desc']).' </p>
			</div>
			<div class="xa-cta-area__button">
				<a class="xa-buttons__btn xa-buttons__btn-type1" href="' . esc_url( $settings['xaddons_button_link']['url'] ) . '" target="' . esc_attr( $xaddons_target ) . '">
					<div class="xa-buttons__inside">';

					

					if ( $settings['xaddons_button_dir'] == 'style-1' && $settings['xaddons_use_icon'] == 'yes' ) {
						echo '<span><i class="' . esc_attr( $settings['xaddons_button_icon']['value'] ) . '"></i></span>';
					}
				
					echo '<span>' . esc_html( $settings['xaddons_button_text'] ) . '</span>';
				
					if ( $settings['xaddons_button_dir'] == 'style-2'  && $settings['xaddons_use_icon'] == 'yes') {
						echo '<span><i class="' . esc_attr( $settings['xaddons_button_icon']['value'] ) . '"></i></span>';
					}
				
					echo '
					</div>
				</a>
			</div>
		</div>';
	}


}