<?php

/**
 * Widget Class.
 *
 * @since 1.0.0
*/

use \Elementor\Core\Kits\Documents\Tabs\Global_Typography;

class xaddons_hero_Widget extends \Elementor\Widget_Base {
    
	
	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'xa-hero-widget';
	}

	public function get_title() {
		return __( 'XA: Hero Section', 'x-addons-elementor' );
	}

	public function get_icon() {
		return 'eicon-featured-image';
	}

    public function get_keywords() {
		return [ 'xaddons', 'banner', 'cover', 'images' ];
	}

	public function get_categories() {
		return [ 'x-addons' ];
	}

	protected function register_controls() {

		$this->register_content_controls();
        $this->register_style_controls();
	}

	function register_content_controls(){
		// Tab #1
		$this->start_controls_section(
			'xaddons_tab_one',
			[
				'label' => __( 'Hero Content', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
            'xaddons_thumbnail_option',
            [
                'label' => __('Show Hero Thumbnail', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'x-addons-elementor'),
                'label_off' => __('No', 'x-addons-elementor'),
                'default' => 'yes',
            ]
        );

		
		$this->add_control(
			'xaddons_thumbnail',
			[
				'label' => __( 'Hero Thumbnail', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
				'condition' => [
                    'xaddons_thumbnail_option' => 'yes',
                ],
			]
		);		

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'xaddons_anim_text',
			[
				'label' => esc_html__( 'Animate Text', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'xaddons_anim_lists',
			[
				'label' => __( 'All Animate List', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'separator' => 'before',   
				'default' => [
					[
						'xaddons_anim_text' => __( 'Web Digital Agency', 'x-addons-elementor' ),
					],
					[
						'xaddons_anim_text' => __( 'SEO Optimize Service', 'x-addons-elementor' ),
					],
					[
						'xaddons_anim_text' => __( 'Digital Marketing Solutions', 'x-addons-elementor' ),
					],
				],
			]
		);

		$this->add_control(
			'xaddons_title',
			[
				'label' => __( 'Hero Title', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'Grow Your Business with Our Expert Digital <span>Web Agency</span> Services!',
				'label_block' => true,
				'separator' => 'before',   
			]
		);

		$this->add_control(
			'xaddons_desc',
			[
				'label' => __( 'Hero Content', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque molestie faucibus lorem ut gravida. Vestibulum viverra elementum diam Quisque convallis metus non lectus lacinia, ut sodales arcu condimentum.',
			]
		);

		$this->add_control(
			'xaddons_button_text',
			[
				'label' => __( 'Video Button Text', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Overview',
				'label_block' => true,
				'separator' => 'before',   
			]
		);

		$this->add_control(
			'xaddons_button_url',
			[
				'label' => __( 'Youtube Video ID', 'x-addons-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Y7cpCDlRfV0',
				'label_block' => true,
			]
		);

		$this->end_controls_section();
	}


	function register_style_controls(){

		$this->start_controls_section(
            'xaddons_title_style',
            [
                'label' => __('Title style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_responsive_control(
            'xaddons_title_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-hero-area__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_title_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-hero-area__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_color',
            [
                'label' => __('Title Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-hero-area__title' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_background',
            [
                'label' => __('Title Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-hero-area__title' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_title_border',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-hero-area__title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'xaddons_title_highlight',
            [
                'type' => \Elementor\Controls_Manager::HEADING,
                'label' => __('Highlight Text', 'x-addons-elementor'),
                'separator' => 'before'
            ]
        );
        $this->add_control(
            'xaddons_title_highlight_color',
            [
                'label' => __('Highlight Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-hero-area__title span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_highlight_bg',
            [
                'label' => __('Highlight Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-hero-area__title span' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_title_highlight_radius',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-hero-area__title span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();


		$this->start_controls_section(
            'xaddons_anim_style',
            [
                'label' => __('Animate List style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_responsive_control(
            'xaddons_anim_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-hero__animate' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_anim_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-hero__animate' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_anim_color',
            [
                'label' => __('Title Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-hero__animate' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_anim_background',
            [
                'label' => __('Title Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-hero__animate' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_anim_border',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-hero__animate' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


		$this->end_controls_section();


		$this->start_controls_section(
            'xaddons_thumbnail_style',
            [
                'label' => __('Hero Thumbnail style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'xaddons_thumbnail_option' => 'yes',
				],
			], 
        );

		$this->add_responsive_control(
            'xaddons_thumbnail_width',
            [
                'label' => esc_html__('Width', 'x-addons-elementor'),
                'type' =>  \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%', 'px'],
                'desktop_default' => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'range' => [
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 10,
                        'max' => 1000,
                    ],

                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-thumbnail img' => 'width: {{SIZE}}{{UNIT}} !important;',

                ],
            ]
        );

        $this->add_control(
            'xaddons_thumbnail_auto_height',
            [
                'label' => __('Image auto height', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('On', 'x-addons-elementor'),
                'label_off' => __('Off', 'x-addons-elementor'),
                'default' => 'yes',
            ]
        );
        $this->add_responsive_control(
            'xaddons_thumbnail_height',
            [
                'label' => esc_html__('Height', 'x-addons-elementor'),
                'type' =>  \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%', 'px'],
                'desktop_default' => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'range' => [
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 10,
                        'max' => 1000,
                    ],

                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-thumbnail img' => 'height: {{SIZE}}{{UNIT}} !important;',

                ],
                'condition' => [
                    'xaddons_thumbnail_auto_height' => '',
                ],
            ]
        );

        $this->add_control(
            'xaddons_thumbnail_div_height',
            [
                'label' => __('Image div Height', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ]
                ],
                'condition' => [
                    'xaddons_thumbnail_auto_height' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-thumbnail' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_thumbnail_border',
                'selector' => '{{WRAPPER}} .xa-thumbnail img',
            ]
        );

        $this->add_control(
            'xaddons_thumbnail_radius',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-thumbnail img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],

            ]
        );


        $this->add_responsive_control(
            'xaddons_thumbnail_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-thumbnail' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_thumbnail_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-thumbnail' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'xaddons_thumbnail_bg_color',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .xa-thumbnail' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_thumbnail_bg_radius',
            [
                'label' => __('Background Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-thumbnail' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],

            ]
        );
       

		$this->end_controls_section();


		$this->start_controls_section(
            'xaddons_typography_style',
            [
                'label' => __('Typography style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_title_typography',
                'label' => __('Title Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} ..xa-info-card__title a',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_desc_typography',
                'label' => __('Content Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-wrapper .xa-info-card__desc',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_button_typography',
                'label' => __('Content Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-wrapper .xa-buttons__info',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );


		$this->end_controls_section();


	}


	/**

	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected

	 */

	 protected function render() {

        $settings = $this->get_settings_for_display();
		
        echo '
		<section class="xa-hero-area  xa-wrapper">
			<div class="xa-container">
				<div class="xa-row">
					<div class="xa-column xa-hero-area--column1">
						<div class="xa-hero-area__content">
                            <div id="typed-strings">';
								foreach($settings['xaddons_anim_lists'] as $alist){
                                echo'<p>'.esc_html($alist['xaddons_anim_text']).'</p>';
                                }echo'
                            </div>
                            <span id="typed"></span>

							<h1 class="xa-hero-area__title">'.wp_kses_post($settings['xaddons_title']).'</h1>
							<p class="xa-hero-area__text">'.esc_html($settings['xaddons_desc']).'</p>
							<div class="xa-hero-area__btn">
								<a class="theme-btn xa-youtube-btn video"  data-video-id="'.esc_attr($settings['xaddons_button_url']).'"><i class="fa fa-play"></i>'.esc_html($settings['xaddons_button_text']).'</a>
							</div>
						</div>
					</div>';
					if($settings['xaddons_thumbnail_option'] == true){
						echo'
						<div class="xa-column xa-hero-area--column2">
							<div class="xa-hero-area__img">
                                <div class="xa-thumbnail">
                                    <img src="'. esc_url($settings['xaddons_thumbnail']['url']) . '">
                                </div>
							</div>
						</div>';
					}echo'
				</div>
			</div>
		</section>';

	}

}