<?php

/**
 * Widget Class.
 *
 * @since 1.0.0
*/
use \Elementor\Core\Kits\Documents\Tabs\Global_Typography;
class xaddons_info_card_Widget extends \Elementor\Widget_Base {
	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'xa-info-card';
	}

	public function get_title() {
		return __( 'XA: Info Card', 'x-addons-elementor' );
	}

	public function get_icon() {
		return 'eicon-featured-image';
	}

	public function get_keywords() {
		return [ 'infobox', 'service', 'icon', 'iconbox' ];
	}

	public function get_categories() {
		return [ 'x-addons' ];
	}

	protected function register_controls() {

		$this->register_content_controls();
        $this->register_style_controls();
	}

	protected function register_content_controls() {

		// Tab #1
		$this->start_controls_section(
			'xaddons_tab_one',
			[
				'label' => __( 'Show Icons', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
            'xaddons_icon_show',
            [
                'label' => __('Show Icons?', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'x-addons-elementor'),
                'label_off' => __('No', 'x-addons-elementor'),
                'default' => 'yes',
            ]
        );

		$this->add_control(
            'xaddons_icon_position',
            [
                'label' => __('Icon position', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'xa-ic-left xa-ic-side' => [
                        'title' => __('Left', 'x-addons-elementor'),
                        'icon' => 'fas fa-arrow-left',
                    ],
                    'xa-ic-top' => [
                        'title' => __('Top', 'x-addons-elementor'),
                        'icon' => 'fas fa-arrow-up',
                    ],
                    'xa-ic-right xa-ic-side' => [
                        'title' => __('Right', 'x-addons-elementor'),
                        'icon' => 'fas fa-arrow-right',
                    ],

                ],
                'default' => 'xa-ic-top',
                'toggle' => false,
                'condition' => [
                    'xaddons_icon_show' => 'yes',
                ],     
            ]
        );

        $this->add_control(
            'xaddons_icon_type',
            [
                'label' => __('Icon Type', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'xa_icon' => [
                        'title' => __('Icon', 'x-addons-elementor'),
                        'icon' => 'fas fa-info',
                    ],
                    'xa_image' => [
                        'title' => __('Image', 'x-addons-elementor'),
                        'icon' => 'far fa-image',
                    ],

                ],
                'default' => 'xa_icon',
                'toggle' => true,
				'condition' => [
                    'xaddons_icon_show' => 'yes',
                ],   
            ]
        );

		$this->add_control(
			'xaddons_icon',
			[
				'label' => esc_html__( 'Button Icon', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::ICONS,      
				'default' => [
					'value' => 'fas fa-paint-brush',
					'library' => 'solid',
				],
                'condition' => [
                    'xaddons_icon_type' => 'xa_icon',
                    'xaddons_icon_show' => 'yes',
                ],     
			]
		);

		$this->add_control(
			'xaddons_icon_img',
			[
				'label' => __( 'Image Thumbnail', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ], 
				'condition' => [
                    'xaddons_icon_type' => 'xa_image',
                    'xaddons_icon_show' => 'yes',
                ],   
				'separator' => 'before',
			]
		);		
		
		$this->end_controls_section();

		$this->start_controls_section(
			'xaddons_tab_two',
			[
				'label' => __( 'Title & Description', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);


		$this->add_control(
			'xaddons_title',
			[
				'label' => __( 'Heading Title', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'Best Web Solutions',
				'label_block' => true,
				'separator' => 'before',   
			]
		);


		$this->add_control(
			'xaddons_desc',
			[
				'label' => __( 'Description', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'Continually network virtual strategic theme areas vis-a-vis',
				'rows' => 5,
				'dynamic' => [
					'active' => true,
				]
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'xaddons_tab_three',
			[
				'label' => __( 'Button', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'xaddons_button_text',
			[
				'label' => __( 'Button Text', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Our Services',
				'placeholder' => __('Our Services', 'x-addons-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'xaddons_button_link',
			[
				'label' => __( 'Button Link', 'x-addons-elementor' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [ 'url' => '#',],
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'xaddons_tab_four',
			[
				'label' => __( 'Basic Settings', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'xaddons_content_position',
			[
				'label' => esc_html__( 'Content Alignment', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
                'default' => 'text-center',
				'options' => [
					'text-start' => [
                        'title' => __('Left', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'text-center' => [
                        'title' => __('Center', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'text-end' => [
                        'title' => __('Right', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],
				],
                'toggle' => false,
			]
		);

		$this->add_responsive_control(
            'xaddons_icon_justify',
            [
                'label' => __('Icon Position', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => __('Start', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'flex-end' => [
                        'title' => __('End', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],

                ],
                'default' => 'center',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__main' => 'justify-content: {{VALUE}};',
                ],
            ]
        );
		
		$this->add_responsive_control(
            'xaddons_icon_align',
            [
                'label' => __('Icon Alignment', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => __('Start', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'flex-end' => [
                        'title' => __('End', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],

                ],
                'default' => 'flex-start',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__main' => 'align-items: {{VALUE}};',
                ],
            ]
        );

	
		$this->end_controls_section();
	}

	function register_style_controls(){


		$this->start_controls_section(
            'xaddons_card_style',
            [
                'label' => __('Card Style', 'xaddons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'xaddons_card_min_height',
            [
                'label' => __('Minimum Height', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 1000,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card' => 'min-height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'xaddons_card_padding',
            [
                'label' => __('Padding', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_card_margin',
            [
                'label' => __('Margin', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_box_border',
                'selector' => '{{WRAPPER}} .xa-info-card'

            ]
        );

        $this->add_responsive_control(
            'xaddons_card_border_radius',
            [
                'label' => __('Border Radius', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_box_shadow',
                'exclude' => [
                    'box_shadow_position',
                ],
                'selector' => '{{WRAPPER}} .xa-info-card'
            ]
        );

        $this->add_control(
            'xaddons_card_bg_color',
            [
                'label' => __('Background Color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card' => 'background-color: {{VALUE}};',
                ],

            ]
        );
        $this->end_controls_section();

		$this->start_controls_section(
            'xaddons_icon_style',
            [
                'label' => __('Icon or Image', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'xaddons_icon_show' => 'yes',
                ],
            ]
        );
        
        $this->add_responsive_control(
            'xaddons_icon_size',
            [
                'label' => __('Icon Size', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__icon i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .xa-info-card__icon svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'xaddons_icon_type' => 'xa_icon'
                ]
            ]
        );
		
        $this->add_responsive_control(
            'xaddons_icon_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__icon.xa_icon' => 'padding: {{SIZE}}{{UNIT}} !important;',
					'{{WRAPPER}} .xa-info-card__icon.xa_image img,{{WRAPPER}} .xa-info-card__icon.xa_image svg' => 'padding: {{SIZE}}{{UNIT}} !important;',	
                ],
            ]
        );
		
        $this->add_responsive_control(
            'xaddons_icon_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
            'xaddons_image_width',
            [
                'label' => __('Image Width', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 400,
                    ],
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__icon img' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'xaddons_icon_type' => 'xa_image'
                ]
            ]
        );

        $this->add_responsive_control(
            'xaddons_image_height',
            [
                'label' => __('Image Height', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 400,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__icon img' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'xaddons_icon_type' => 'xa_image'
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_icon_border',
                'selector' => '{{WRAPPER}} .xa-info-card__icon.xa_icon,{{WRAPPER}} .xa-info-card__icon img'

            ]
        );

        $this->add_responsive_control(
            'xaddons_icon_border_radius',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
				'selectors' => [
                    '{{WRAPPER}} .xa-info-card__icon img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .xa-info-card__icon.xa_icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_info_block_shadow',
                'exclude' => [
                    'box_shadow_position',
                ],
                'selector' => '{{WRAPPER}} .xa-info-card__icon.xa_icon,{{WRAPPER}} .xa-info-card__icon img'
            ]
        );

        $this->add_control(
            'xaddons_icon_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__icon i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .xa-info-card__icon svg' => 'fill: {{VALUE}}',
                ],
                'condition' => [
                    'xaddons_icon_type' => 'xa_icon'
                ]
            ]
        );

        $this->add_control(
            'xaddons_icon_bg_color',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__icon.xa_icon,{{WRAPPER}} .xa-info-card__icon img' => 'background-color: {{VALUE}};',
                ],

            ]
        );


        $this->end_controls_section();
		
		$this->start_controls_section(
            'xaddons_title_desc_style',
            [
                'label' => __('Title & Description style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_control(
            'xaddons_title_style',
            [
                'type' => \Elementor\Controls_Manager::HEADING,
                'label' => __('Title Style', 'x-addons-elementor'),
                'separator' => 'after'
            ]
        );

		$this->add_responsive_control(
            'xaddons_title_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_title_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-info-card__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__title a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_background',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__title' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_title_border',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'xaddons_desc_style',
            [
                'type' => \Elementor\Controls_Manager::HEADING,
                'label' => __('Description Style', 'x-addons-elementor'),
                'separator' => 'after'
            ]
        );

		$this->add_responsive_control(
            'xaddons_desc_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_desc_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-info-card__desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_desc_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__desc' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_desc_bg',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__desc' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_desc_radius',
            [
                'label' => __('Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__desc' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
            'xaddons_button_style',
            [
                'label' => __('Button', 'xaddons-elementor'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'xaddons_button_padding',
            [
                'label' => __('Padding', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'xaddons_button_icon_size',
            [
                'label' => __('Icon Size', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 300,
                    ],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 14,
				],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__info i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .xa-buttons__info svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_button_border',
                'selector' => '{{WRAPPER}} .xa-buttons__info',
            ]
        );

        $this->add_control(
            'xaddons_button_border_radius',
            [
                'label' => __('Border Radius', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-buttons__info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_button_box_shadow',
                'selector' => '{{WRAPPER}} .xa-buttons__info',
            ]
        );

        $this->add_control(
            'xaddons_button_colors',
            [
                'label' => __('Button color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs('xaddons_button_tabs');


       
        
        $this->end_controls_tabs();

        $this->end_controls_section();


		

		$this->start_controls_section(
            'xaddons_typography_style',
            [
                'label' => __('Typography style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_title_typography',
                'label' => __('Title Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-info-card__title a',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_desc_typography',
                'label' => __('Content Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-info-card__desc',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_button_text_typography',
                'label' => __('Button Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-buttons__info',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );


		$this->end_controls_section();


	}

	/**

	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected

	 */

	 protected function render() {

        $settings = $this->get_settings_for_display();

		// Determine target for link
		$xaddons_target = ( $settings['xaddons_button_link']['is_external'] == true ) ? '_blank' : '_self';
		
        echo '
		<div class="xa-services xa-wrapper xa-alignment">
			<div class="xa-info-card '.esc_attr($settings['xaddons_icon_position']).'">
				<div class="xa-info-card__main">';
					if($settings['xaddons_icon_show'] == true){
						echo'<div class="xa-info-card__icon '.$settings['xaddons_icon_type'].'" >';
							if ($settings['xaddons_icon_type'] == 'xa_icon'){
								echo'<i class="'.esc_attr($settings['xaddons_icon']['value']).'"></i>';
							}else{
								echo'<img src="'.esc_url($settings['xaddons_icon_img']['url']).'" alt="'.esc_attr($settings['xaddons_title']).'">';
							}
							echo'
						</div>';
					}echo'
				</div>
				<div class="xa-info-card__content '.$settings['xaddons_content_position'].'">
					<h3 class="xa-info-card__title"><a href="'.esc_url($settings['xaddons_button_link']['url']).'" target="'.esc_attr($xaddons_target).'">'.esc_html($settings['xaddons_title']).'</a></h3>
					<p class="xa-info-card__desc">'.esc_html($settings['xaddons_desc']).'</p>
					<a class="xa-buttons__info" href="' . esc_url( $settings['xaddons_button_link']['url'] ) . '" target="' . esc_attr( $xaddons_target ) . '"> ' . esc_html( $settings['xaddons_button_text'] ) . ' </a>
				</div>
			</div>
		</div>';

	}

}