<?php

/**
 * Widget Class.
 *
 * @since 1.0.0
*/
use \Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Controls_Manager;
use Elementor\Utils;
class xaddons_list_type_Widget extends \Elementor\Widget_Base {
	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'xa-list-type-widget';
	}

	public function get_title() {
		return __( 'XA: List Type', 'x-addons-elementor' );
	}

	public function get_icon() {
		return 'eicon-featured-image';
	}

    public function get_keywords() {
		return [ 'xaddons', 'icon', 'iconlist', 'number', 'numberlist', 'dots', 'dotlist', ];
	}

	public function get_categories() {
		return [ 'x-addons' ];
	}

	protected function register_controls() {

		$this->register_content_controls();
        $this->register_style_controls();
	}

	protected function register_content_controls() {

		// Tab #1
		$this->start_controls_section(
			'xaddons_tab_one',
			[
				'label' => __( 'List Type', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'xaddons_layout',
			[

				'label' => esc_html__('Layout', 'plugin-name'),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'xa-layout-1' => [
						'title' => esc_html__('Vertical', 'x-addons-elementor'),
						'icon' => 'eicon-editor-list-ul',
					],
					'xa-layout-2' => [
						'title' => esc_html__('Horizontal', 'x-addons-elementor'),
						'icon' => 'eicon-ellipsis-h',
					],
				],
				'default' => 'xa-layout-1',

			]
		);
		
		$repeater = new \Elementor\Repeater();


		$repeater->add_control(
			'xaddons_icon_type',
			[
				'label' => __('Icon Type', 'x-addons-elementor'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'dots' => [
						'title' => __('Dots', 'x-addons-elementor'),
						'icon' => 'eicon-dot-circle-o',
					],
					'number' => [
						'title' => __('Number', 'x-addons-elementor'),
						'icon' => 'eicon-number-field',
					],
					'icon' => [
						'title' => __('Icon', 'x-addons-elementor'),
						'icon' => 'eicon-icon-box',
					],
					'image' => [
						'title' => __('Image', 'x-addons-elementor'),
						'icon' => 'eicon-image-box',
					],
				],
				'default' => 'icon',
				'toggle' => true,
			]
		);

		
		$repeater->add_control(
			'xaddons_list_number',
			[
				'label' => esc_html__( 'List Number', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => '1',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'xaddons_icon_type' => 'number',
				],
			]
		);

		
		$repeater->add_control(
			'xaddons_icon_type_icon',
			[
				'label' => __('Choose Icon', 'x-addons-elementor'),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'far fa-grin-alt',
					'library' => 'fa-solid',
				],
				'condition' => [
					'xaddons_icon_type' => 'icon',
				],
			]
		);


		$repeater->add_control(
			'xaddons_icon_type_image',
			[
				'label' => __('Choose Image', 'x-addons-elementor'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'xaddons_icon_type' => 'image',
				],

			]
		);

		$repeater->add_control(
			'xaddons_list_label',
			[
				'label' => esc_html__( 'List Label', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Phone:',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);

        $repeater->add_control(
			'xaddons_list_info',
			[
				'label' => esc_html__( 'List Info', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => '+123-4567-8901',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$repeater->add_control(
			'xaddons_link_field',
			[
				'label' => __( 'URL Link', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::URL,
				'default' => [ 'url' => '#',],
			]
		);

		$this->add_control(
			'xaddons_lists',
			[
				'label' => __( 'All List', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'list_title' => __( 'Title #1', 'x-addons-elementor' ),
						'list_content' => __( 'List Info', 'x-addons-elementor' ),
					],
				],
			]
		);

		$this->end_controls_section();

		// Tab #2
		$this->start_controls_section(
			'xaddons_tab_two',
			[
				'label' => __( 'List Styles', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);


		$this->end_controls_section();

	}

	function register_style_controls(){

		$this->start_controls_section(
            'xaddons_default_style',
            [
                'label' => __('Basic Style', 'xaddons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		
		$this->add_control(
			'xaddons_space_between',
			[
				'label' => __('Space Between', 'x-addons-elementor'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					]
				],
				'selectors' => [
					'{{WRAPPER}} .xa-list-styles__list' => 'gap: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'xaddons_space_icon_between',
			[
				'label' => __('Icon Space', 'x-addons-elementor'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					]
				],
				'selectors' => [
					'{{WRAPPER}} .xa-list-styles__list li' => 'gap: {{SIZE}}{{UNIT}};',
				],
			]
		);


        $this->add_responsive_control(
            'xaddons_align',
            [
                'label' => __('List Alignment', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => __('Left', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'flex-end' => [
                        'title' => __('Right', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],

                ],
                'default' => 'flex-start',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .xa-alignment' => 'justify-content: {{VALUE}}; display:flex;',
                ],
            ]
        );
		
		$this->add_control(
			'xaddons_text_position',
			[
				'label' => esc_html__( 'Text Position', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'default' => 'text-left',
				'options' => [
					'text-left' => [
                        'title' => __('Left', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'text-center' => [
                        'title' => __('Center', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'text-end' => [
                        'title' => __('Right', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],
				],
                'toggle' => false,
			]
		);



        $this->end_controls_section();

		// $this->start_controls_section(
        //     'xaddons_icon_style',
        //     [
        //         'label' => __('Icon Type Style', 'xaddons-elementor'),
        //         'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        //     ]
        // );

		// $this->add_control(
		// 	'xaddons_icon_image_width',
		// 	[
		// 		'label' => __('Image Width', 'x-addons-elementor'),
		// 		'type' => Controls_Manager::SLIDER,
		// 		'size_units' => ['px'],
		// 		'range' => [
		// 			'px' => [
		// 				'min' => 35,
		// 				'max' => 1000,
		// 				'step' => 1,
		// 			]
		// 		],
		// 		'selectors' => [
		// 			'{{WRAPPER}} .xa-list-styles__icons img' => 'width: {{SIZE}}{{UNIT}};',
		// 		],
		// 	]
		// );

		// $this->add_control(
		// 	'xaddons_icon_image_height',
		// 	[
		// 		'label' => __('Image Height', 'x-addons-elementor'),
		// 		'type' => Controls_Manager::SLIDER,
		// 		'size_units' => ['px'],
		// 		'range' => [
		// 			'px' => [
		// 				'min' => 35,
		// 				'max' => 1000,
		// 				'step' => 1,
		// 			]
		// 		],
		// 		'selectors' => [
		// 			'{{WRAPPER}} .xa-list-styles__icons img' => 'width: {{SIZE}}{{UNIT}};',
		// 		],

		// 	]
		// );

		// $this->add_control(
		// 	'xaddons_icon_size',
		// 	[
		// 		'label' => __('Icon Size', 'x-addons-elementor'),
		// 		'type' => Controls_Manager::SLIDER,
		// 		'size_units' => ['px'],
		// 		'range' => [
		// 			'px' => [
		// 				'min' => 10,
		// 				'max' => 1000,
		// 				'step' => 1,
		// 			]
		// 		],
		// 		'selectors' => [
		// 			'{{WRAPPER}} .xa-list-styles__icons i' => 'font-size: {{SIZE}}{{UNIT}};',
		// 			'{{WRAPPER}} .xa-list-styles__icons svg' => 'width: {{SIZE}}{{UNIT}};',
		// 		],
		// 	]
		// );

		
        // $this->end_controls_section();

		$this->start_controls_section(
            'xaddons_content_style',
            [
                'label' => __('Content Style', 'xaddons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_control(
            'xaddons_content_label_color',
            [
                'label' => __('List Label Color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-list-styles__list li b' => 'color: {{VALUE}};',
                ],

            ]
        );
      
		$this->add_control(
            'xaddons_content_desc_color',
            [
                'label' => __('List Info Color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-list-styles__list li,{{WRAPPER}} .xa-list-styles__list li a' => 'color: {{VALUE}};',
                ],

            ]
        );

		$this->add_control(
			'xaddons_icon_color',
			[
				'label' => __('Icons Color', 'x-addons-elementor'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .xa-list-styles__icons i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .xa-list-styles__icons svg' => 'fill: {{VALUE}};',
				],
			]
		);
		

        $this->end_controls_section();

		$this->start_controls_section(
            'xaddons_label_style',
            [
                'label' => __('Label style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_responsive_control(
            'xaddons_label_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_label_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-info-card__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_label_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-info-card__title a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_label_background',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-list-content__label' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_label_border',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-list-content__label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


		$this->end_controls_section();

		$this->start_controls_section(
            'xaddons_info_style',
            [
                'label' => __('Info style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_responsive_control(
            'xaddons_info_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-list-content__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_info_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-list-content__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_info_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-list-content__title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_info_bg',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-list-content__title' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_info_radius',
            [
                'label' => __('Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-list-content__title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();


		$this->start_controls_section(
            'xaddons_typography_style',
            [
                'label' => __('Typography style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_label_typography',
                'label' => __('Label Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-wrapper span',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_title_typography',
                'label' => __('Title Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-list-content__title,{{WRAPPER}} .xa-list-content__title a',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );



		$this->end_controls_section();
	}

	/**

	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected

	 */

	 protected function render() {

        $settings = $this->get_settings_for_display();

        echo '
        <div class="xa-wrapper xa-alignment xa-list-styles">
            <ul class="xa-list-styles__list '.esc_attr($settings['xaddons_layout']).' '.esc_attr($settings['xaddons_text_position']).'">';
            foreach($settings['xaddons_lists'] as $list){
				echo '<li class="'.esc_attr($list['xaddons_icon_type']).'">';

				// Add icon type handling (image, number, icon, etc.)
				if ( ! empty( $list['xaddons_icon_type'] ) ) {
					if ( $list['xaddons_icon_type'] === 'icon' ) {
						echo '<span class="xa-list-icon"><i class="' . esc_attr( $list['xaddons_icon_type_icon']['value'] ) . '"></i></span>';
					} elseif ( $list['xaddons_icon_type'] === 'image' ) {
						echo '<span class="xa-list-icon"><img src="' . esc_url( $list['xaddons_icon_type_image']['url'] ) . '" alt="' . esc_attr( $list['xaddons_list_label'] ) . '"></span>';
					} elseif ( $list['xaddons_icon_type'] === 'number' ) {
						echo '<span class="xa-list-icon">' . esc_html( $list['xaddons_list_number'] ) . '</span>';
					}
				}
				echo'
				<div class="xa-list-content">
					<span class="xa-list-content__label">' . esc_html( $list['xaddons_list_label'] ) . '</span>';
					if(empty ($list['xaddons_link_field']['url'])){
						echo''.esc_html($list['xaddons_list_info']).'';
					}else{
						echo'<p class="xa-list-content__title"><a href="'.esc_url($list['xaddons_link_field']['url']).'">'.esc_html($list['xaddons_list_info']).'</a></p>';
					}echo'
				</div>';
				echo'
				</li>';
            }echo'
            </ul>
        </div>';

	}

}