<?php
/**
 * Widget Class.
 *
 * @since 1.0.0
*/
class xaddons_logo_carousel_widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Slider widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'xa-logo-carousel';
	}

	
	public function get_title() {
		return __( 'XA: Logo Carousel', 'x-addons-elementor' );
	}

	public function get_icon() {
		return 'eicon-featured-image';
	}

    public function get_keywords() {
		return [ 'xaddons', 'brand', 'slider', 'client', 'image slider' ];
	}
	
	public function get_categories() {
		return [ 'x-addons' ];
	}

	protected function register_controls() {

		$this->register_content_controls();
        $this->register_style_controls();
	}

	protected function register_content_controls() {
		
		
		// Tab One
		$this->start_controls_section(
			'xaddons_tab_one',
			[
				'label' => __( 'Logo Carousel', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'xaddons_image_thumb', [
				'label' => __( 'Thumbnail logo', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
			]
		);

        $repeater->add_control(
			'xaddons_title',
			[
				'label' => __( 'Logo Title', 'x-addons-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Brand',
			]
		);

        $repeater->add_control(
			'xaddons_brand_link',
			[
				'label' => __( 'Brand Link', 'x-addons-elementor' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [ 'url' => '#',],
				'placeholder' => __('https://example-site.com', 'x-addons-elementor'),
			]
		);

		$this->add_control(
			'xaddons_lists',
			[
				'label' => __( 'All Logo List', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'xaddons_image_thumb' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
						'xaddons_title' => __( 'Logo Title', 'x-addons-elementor' ),
						'xaddons_brand_link' => __( '#'),
					],
					[
						'xaddons_image_thumb' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
						'xaddons_title' => __( 'Logo Title', 'x-addons-elementor' ),
						'xaddons_brand_link' => __( '#'),
					],
					[
						'xaddons_image_thumb' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
						'xaddons_title' => __( 'Logo Title', 'x-addons-elementor' ),
						'xaddons_brand_link' => __( '#'),
					],
					[
						'xaddons_image_thumb' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
						'xaddons_title' => __( 'Logo Title', 'x-addons-elementor' ),
						'xaddons_brand_link' => __( '#'),
					],
					[
						'xaddons_image_thumb' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
						'xaddons_title' => __( 'Logo Title', 'x-addons-elementor' ),
						'xaddons_brand_link' => __( '#'),
					],
					[
						'xaddons_image_thumb' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
						'xaddons_title' => __( 'Logo Title', 'x-addons-elementor' ),
						'xaddons_brand_link' => __( '#'),
					],
				],
			]
		);
		
		$this->end_controls_section();
		
		// Settings Section
		$this->start_controls_section(
			'xaddons_tab_two',
			[
				'label' => __( 'Slider Settings', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'xaddons_slider_large_device',
			[
				'label' => __( 'Slide Column Large', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'return_value' => 'yes',
				'default' => '5',
			]
		);
		
		$this->add_control(
			'xaddons_slider_laptop',
			[
				'label' => __( 'Slide Column Laptop', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'return_value' => 'yes',
				'default' => '5',
			]
		);
		
		$this->add_control(
			'xaddons_slider_tab',
			[
				'label' => __( 'Slide Column Tab', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'return_value' => 'yes',
				'default' => '2',
			]
		);
		
		$this->add_control(
			'xaddons_slider_mobile',
			[
				'label' => __( 'Slide Column Mobile', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'return_value' => 'yes',
				'default' => '1',
			]
		);
		
		$this->add_control(
			'xaddons_slider_autoplay',
			[
				'label' => __( 'Slide Autoplay?', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'x-addons-elementor' ),
				'label_off' => __( 'Hide', 'x-addons-elementor' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'xaddons_slider_autoplay_times',
			[
				'label' => __( 'Autoplay Timeout', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => '5000',
				'condition' => [
					'xaddons_slider_autoplay' => 'yes',
				],
			]
		);

		$this->add_control(
			'xaddons_slider_loop',
			[
				'label' => __( 'Slide Loop?', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'x-addons-elementor' ),
				'label_off' => __( 'Hide', 'x-addons-elementor' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'xaddons_slider_mode',
			[
				'label' => __( 'Center Mode?', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'x-addons-elementor' ),
				'label_off' => __( 'Hide', 'x-addons-elementor' ),
				'return_value' => 'yes',
			]
		);

		
		$this->add_control(
			'xaddons_slider_speed',
			[
				'label' => __( 'Slide Speed while changes', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => '600',
			]
		);	

		$this->add_control(
			'xaddons_slider_nav',
			[
				'label' => __( 'Slide Nav', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'x-addons-elementor' ),
				'label_off' => __( 'Hide', 'x-addons-elementor' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		
		$this->add_control(
			'xaddons_slider_dots',
			[
				'label' => __( 'Slide Dots', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'x-addons-elementor' ),
				'label_off' => __( 'Hide', 'x-addons-elementor' ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->end_controls_section();

	}

	function register_style_controls(){

		$this->start_controls_section(
            'xaddons_default_style',
            [
                'label' => __('Default Style', 'xaddons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_responsive_control(
            'xaddons_default_padding',
            [
                'label' => __('Padding', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-brand-slider' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'xaddons_default_margin',
            [
                'label' => __('Margin', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-brand-slider' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_default_border',
                'selector' => '{{WRAPPER}} .xa-brand-slider'

            ]
        );

        $this->add_responsive_control(
            'xaddons_default_border_radius',
            [
                'label' => __('Border Radius', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-brand-slider' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_default_shadow',
                'exclude' => [
                    'box_shadow_position',
                ],
                'selector' => '{{WRAPPER}} .xa-brand-slider'
            ]
        );

        $this->add_control(
            'xaddons_default_bg_color',
            [
                'label' => __('Background Color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-brand-slider' => 'background-color: {{VALUE}};',
                ],

            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
            'xaddons_image_style',
            [
                'label' => __('Image Style', 'xaddons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_responsive_control(
            'xaddons_image_width',
            [
                'label' => __('Image Width', 'x-addons-elementor'),
                'description' => __('Keep empty for real image width.', 'x-addons-elementor'),
                'type' =>  \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%', 'px', 'em', 'rem'],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-brand-logos img' => 'min-width: {{SIZE}}{{UNIT}};max-width: {{SIZE}}{{UNIT}};'
                ],

            ]
        );

		$this->add_responsive_control(
            'xaddons_image_custom_height',
            [
                'label' => __('Image Custom height', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('On', 'x-addons-elementor'),
                'label_off' => __('Off', 'x-addons-elementor'),
                'default' => 'false',
            ]
        );

		$this->add_responsive_control(
            'xaddons_image_height',
            [
                'label' => __('Image Height', 'x-addons-elementor'),
                'description' => __('Keep empty for real image width.', 'x-addons-elementor'),
                'type' =>  \Elementor\Controls_Manager::SLIDER,
               	'size_units' => ['px'],
				   'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .xa-brand-logos img' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'xaddons_image_custom_height' => 'yes',
                ],

            ]
        );

		$this->add_responsive_control(
            'xaddons_image_padding',
            [
                'label' => __('Padding', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-brand-logos img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'xaddons_image_margin',
            [
                'label' => __('Margin', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-brand-logos img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
		
		$this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_image_border',
                'selector' => '{{WRAPPER}} .xa-brand-logos  img'

            ]
        );

        $this->add_responsive_control(
            'xaddons_image_border_radius',
            [
                'label' => __('Border Radius', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-brand-logos  img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_image_shadow',
                'exclude' => [
                    'box_shadow_position',
                ],
                'selector' => '{{WRAPPER}} .xa-brand-logos img'
            ]
        );

        $this->add_control(
            'xaddons_image_bg_color',
            [
                'label' => __('Background Color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-brand-logos img' => 'background-color: {{VALUE}};',
                ],

            ]
        );


        $this->end_controls_section();
	}

	/**
	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	 
	 
	 protected function render() {

        $settings = $this->get_settings_for_display();
        
		
		if($settings['xaddons_slider_autoplay'] == 'yes'){
			$xaddons_slider_autoplay = 'true';
		} else{
			$xaddons_slider_autoplay = 'false';
		}

		if($settings['xaddons_slider_loop'] == 'yes'){
			$xaddons_slider_loop = 'true';
		} else{
			$xaddons_slider_loop = 'false';
		}

		if($settings['xaddons_slider_mode'] == 'yes'){
			$xaddons_slider_mode = 'true';
		} else{
			$xaddons_slider_mode = 'false';
		}


		if($settings['xaddons_slider_nav'] == 'yes'){
			$xaddons_slider_nav = 'true';
		} else{
			$xaddons_slider_nav = 'false';
		}

		if($settings['xaddons_slider_dots'] == 'yes'){
			$xaddons_slider_dots = 'true';
		} else{
			$xaddons_slider_dots = 'false';
		}
	
		$xaddons_dynamic_number = wp_rand(239329329, 393293293);

		echo '
		<script>
			jQuery(document).ready(function(){
				setInterval(function(){ 
					jQuery(".xa-brand-carousel--'.esc_attr($xaddons_dynamic_number).'").slick({
						slidesToShow:'.esc_js($settings['xaddons_slider_laptop']).',
						slidesToScroll: 1,
						autoplay: '.esc_js($xaddons_slider_autoplay).',
						infinite: '.esc_js($xaddons_slider_loop).',
						centerMode: '.esc_js($xaddons_slider_mode).',
						speed:'.esc_js($settings['xaddons_slider_speed']).',
						autoplayHoverPause: true,
						arrows: '.esc_js($xaddons_slider_nav).',';
						if($settings['xaddons_slider_nav'] == 'yes'){
							echo'
							prevArrow: ".xa-slider-nav__prev-'.esc_attr($xaddons_dynamic_number).'",
							nextArrow: ".xa-slider-nav__next-'.esc_attr($xaddons_dynamic_number).'",';
						}echo'
						dots: '.esc_js($xaddons_slider_dots).',';
						if($xaddons_slider_autoplay == 'true'){
							echo 'autoplaySpeed:'.esc_js($settings['xaddons_slider_autoplay_times']).', ';
						}
						echo '
						responsive:[
                            {
                                breakpoint: 767,
                                settings: {
                                    slidesToShow: '.esc_js($settings['xaddons_slider_mobile']).',
                                }
                            },
                            {
                                breakpoint: 1025,
                                settings: {
                                    slidesToShow: '.esc_js($settings['xaddons_slider_tab']).',
                                }
                            },
                            {
                                breakpoint: 1500,
                                settings: {
                                    slidesToShow: '.esc_js($settings['xaddons_slider_laptop']).',
                                }
                            },
							{
                                breakpoint: 3000,
                                settings: {
                                    slidesToShow: '.esc_js($settings['xaddons_slider_large_device']).',
                                }
                            },
                        ]
					}); 
					}, 10);
			});
		</script>';
		
		echo '	
		<div class="xa-brand-slider xa-wrapper">
			<div class="xa-brand-carousel--'.esc_attr($xaddons_dynamic_number).'">';
				foreach($settings['xaddons_lists'] as $list){
					echo '
					<div class="xa-brand-carousel__single">';
                        if(!empty($list['xaddons_image_thumb']['url'])){
                            echo '
                            <div class="xa-brand-logos">
                                <a href="'.esc_url($list['xaddons_brand_link']['url']).'"><img src="'.esc_url($list['xaddons_image_thumb']['url']).'" title="'.esc_attr($list['xaddons_title']).'" alt="'.esc_attr($list['xaddons_title']).'"></a>
                            </div>';
                        }echo'
					</div>';
                }echo'

			</div>';
			if($settings['xaddons_slider_nav'] == 'yes'){
			echo'
			<div class="xa-slider-nav">
				<div class="xa-slider-nav__prev-'.esc_attr($xaddons_dynamic_number).' xa-slider-nav__prev">
					<i class="fas fa-chevron-left"></i>
				</div>
				<div class="xa-slider-nav__next-'.esc_attr($xaddons_dynamic_number).'  xa-slider-nav__next">
					<i class="fas fa-chevron-right"></i>
				</div>
			</div>';
			}echo'
		</div>';
	}
}