<?php
/**
 * Widget Class for Mailchimp Form (Shortcode-based).
 *
 * @since 1.0.0
 */
class xaddons_mailchimp_form_widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'xa-mailchimp-form';
    }

    public function get_title() {
        return __( 'XA: Mailchimp Form', 'x-addons-elementor' );
    }

    public function get_icon() {
        return 'eicon-mailchimp';
    }

    public function get_keywords() {
        return [ 'xaddons', 'mailchimp', 'newsletter', 'subscribe' ];
    }

    public function get_categories() {
        return [ 'x-addons-elementor' ];
    }

    protected function register_controls() {
        // Tab One
        $this->start_controls_section(
            'xaddons_tab_one',
            [
                'label' => __( 'Mailchimp Form', 'x-addons-elementor' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        // Add style control
        $this->add_control(
            'xaddons_show_style',
            [
                'label' => __('Show Default Style?', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'x-addons-elementor'),
                'label_off' => __('No', 'x-addons-elementor'),
                'default' => '',
            ]
        );

        // Add custom form class control
        $this->add_control(
            'xaddons_form_class',
            [
                'label' => esc_html__( 'Form Class', 'x-addons-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'condition' => [
                    'xaddons_show_style' => '',
                ],
            ]
        );

        // Add form label control
        $this->add_control(
            'xaddons_label',
            [
                'label' => esc_html__( 'Form Label', 'x-addons-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Join our newsletter',
                'label_block' => true,
                'condition' => [
                    'xaddons_show_style' => 'yes',
                ],
            ]
        );

        // Add form title control
        $this->add_control(
            'xaddons_title',
            [
                'label' => esc_html__( 'Form Title', 'x-addons-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Subscribe to Our Newsletter',
                'label_block' => true,
                'condition' => [
                    'xaddons_show_style' => 'yes',
                ],
            ]
        );

        // Add textbox for Mailchimp form shortcode
        $this->add_control(
            'mailchimp_form_shortcode',
            [
                'label' => __( 'Mailchimp Form Shortcode', 'x-addons-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => '',
                'placeholder' => '[mc4wp_form id="YOUR_FORM_ID"]', // Placeholder for the user
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $mailchimp_form_shortcode = $settings['mailchimp_form_shortcode'];

        if ($settings['xaddons_show_style'] == 'yes') {
            echo '<div class="xa-wrapper xa-mailchimp-form">';
        } else {
            echo '<div class="' . esc_attr( $settings['xaddons_form_class'] ) . '">';
        }

        if ($settings['xaddons_show_style'] == 'yes') {
            echo '
            <div class="xa-mailchimp-form__head">
                <p class="xa-mailchimp-form__label">' . esc_html( $settings['xaddons_label'] ) . '</p>
                <h4 class="xa-mailchimp-form__title">' . esc_html( $settings['xaddons_title'] ) . '</h4>
            </div>';
        }

        echo '<div class="xa-mailchimp-form__body">';

        // Check if the Mailchimp form shortcode is entered
        if ($mailchimp_form_shortcode) {
            // Render the Mailchimp form using the shortcode provided
            echo do_shortcode( esc_html( $mailchimp_form_shortcode ) );
        } else {
            echo '<p>' . esc_html__( 'Please enter a Mailchimp form shortcode.', 'x-addons-elementor' ) . '</p>';
        }

        echo '</div></div>';
    }
}
