<?php

/**
 * Widget Class.
 *
 * @since 1.0.0
*/

use Elementor\Controls_Manager;
use Elementor\Group_Control_Box_Shadow;

class xaddons_progress_bar_Widget extends \Elementor\Widget_Base {
	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'xa-progress-bar-widget';
	}

	public function get_title() {
		return __( 'XA: Progress Bar', 'x-addons-elementor' );
	}

	public function get_icon() {
		return 'eicon-featured-image';
	}

	public function get_keywords() {
		return [ 'xaddons', 'progresslist', 'info', 'skills'];
	}

	public function get_categories() {
		return [ 'x-addons' ];
	}


	protected function register_controls() {

		$this->register_content_controls();
        $this->register_style_controls();
	}



	protected function register_content_controls() {

		// Tab #1
		$this->start_controls_section(
			'xaddons_tab_one',
			[
				'label' => __( 'List Style', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);


		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'xaddons_list_label',
			[
				'label' => esc_html__( 'List Label', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Web Design',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'xaddons_list_percent',
			[
				'label' => __('List Percent', 'x-addons-elementor'),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'unit' => '%',
					'size' => 95
				],
				'size_units' => ['%'],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'dynamic' => [
					'active' => true,
				]
			]
		);

        $repeater->add_control(
			'xaddons_list_percent_after',
			[
				'label' => esc_html__( 'List Percent', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => '%',
				'label_block' => true,
			]
		);


		$this->add_control(
			'xaddons_lists',
			[
				'label' => __( 'All List', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'xaddons_list_label' => __( 'Web Design', 'x-addons-elementor' ),
						'xaddons_list_percent' => ['size' => 70, 'unit' => '%'],
						'xaddons_list_percent_after' => __( '%'),
					],
					[
						'xaddons_list_label' => __( 'WordPress', 'x-addons-elementor' ),
						'xaddons_list_percent' => ['size' => 80, 'unit' => '%'],
						'xaddons_list_percent_after' => __( '%'),
					],
					[
						'xaddons_list_label' => __( 'Elementor', 'x-addons-elementor' ),
						'xaddons_list_percent' => ['size' => 90, 'unit' => '%'],
						'xaddons_list_percent_after' => __( '%'),
					],
				],
			]
		);

		$this->end_controls_section();

		// Tab #2
		$this->start_controls_section(
			'xaddons_tab_two',
			[
				'label' => __( 'List Styles', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_responsive_control(
            'xaddons_align',
            [
                'label' => __('List Alignment', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => __('Left', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'flex-end' => [
                        'title' => __('Right', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],

                ],
                'default' => 'flex-start',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .xa-alignment' => 'justify-content: {{VALUE}}; display:flex;',
                ],
            ]
        );
		
		$this->add_control(
			'xaddons_text_position',
			[
				'label' => esc_html__( 'Text Position', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'default' => 'text-left',
				'options' => [
					'text-left' => [
                        'title' => __('Left', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'text-center' => [
                        'title' => __('Center', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'text-end' => [
                        'title' => __('Right', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],
				],
                'toggle' => false,
			]
		);

		$this->end_controls_section();

	}

	function register_style_controls(){

		$this->start_controls_section(
            'xaddons_default_style',
            [
                'label' => __('Basic Style', 'xaddons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'xaddons_default_padding',
            [
                'label' => __('Padding', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-progress__box ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_default_margin',
            [
                'label' => __('Margin', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-progress__box ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'xaddons_default_border',
                'selector' => '{{WRAPPER}} .xa-progress__box '

            ]
        );

        $this->add_responsive_control(
            'xaddons_default_border_radius',
            [
                'label' => __('Border Radius', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-progress__box ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'xaddons_default_shadow',
                'exclude' => [
                    'box_shadow_position',
                ],
                'selector' => '{{WRAPPER}} .xa-progress__box '
            ]
        );

        $this->add_control(
            'xaddons_default_bg_color',
            [
                'label' => __('Background Color', 'xaddons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-progress__box ' => 'background-color: {{VALUE}};',
                ],

            ]
        );
        $this->end_controls_section();


		$this->start_controls_section(
			'xaddons_skill_bar',
			[
				'label' => __('Skill Bars', 'x-addons-elementor'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'xaddons_skill_bar_height',
			[
				'label' => __('Height', 'x-addons-elementor'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 250,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .xa-progress__single .progress' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'xaddons_skill_bar_space',
			[
				'label' => __('Spacing Between', 'x-addons-elementor'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 250,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .xa-progress__single:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'xaddons_skill_bar_radius',
			[
				'label' => __('Border Radius', 'x-addons-elementor'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors' => [
					'{{WRAPPER}} .xa-progress__single .progress' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

	}

	/**

	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected

	 */

	 protected function render() {

        $settings = $this->get_settings_for_display();

        echo '
		<div class="xa-progress xa-wrapper xa-alignment">
			<div class="xa-progress__box '.esc_attr($settings['xaddons_text_position']).'">';
				foreach($settings['xaddons_lists'] as $list){
				echo'
				<div class="xa-progress__single">
					<h3 class="progress-title">'.esc_html($list['xaddons_list_label']).'</h3>
					<div class="progress">
						<div class="progress-bar" style="width:'.esc_attr($list['xaddons_list_percent']['size']).'%;">
							<div class="progress-value">'.esc_html($list['xaddons_list_percent']['size']).''.esc_html($list['xaddons_list_percent_after']).'</div>
						</div>
					</div>
				</div>';
				}echo'
			</div>
		</div>';

	}

}