<?php

/**
 * Widget Class.
 *
 * @since 1.0.0
*/
use \Elementor\Core\Kits\Documents\Tabs\Global_Typography;
class xaddons_section_title_Widget extends \Elementor\Widget_Base {
	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'xa-section-title-widget';
	}

	public function get_title() {
		return __( 'XA: Section Title', 'x-addons-elementor' );
	}

	public function get_icon() {
		return 'eicon-featured-image';
	}

	public function get_keywords() {
		return [ 'xaddons', 'heading', 'sectionheading'];
	}

	public function get_categories() {
		return [ 'x-addons' ];
	}

	protected function register_controls() {

		$this->register_content_controls();
        $this->register_style_controls();
	}

	protected function register_content_controls() {

		// Tab #1
		$this->start_controls_section(
			'xaddons_tab_one',
			[
				'label' => __( 'Section Title', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
            'xaddons_label_show',
            [
                'label' => __('Show Label?', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'x-addons-elementor'),
                'label_off' => __('No', 'x-addons-elementor'),
                'default' => 'yes',
            ]
        );
		
		$this->add_control(
			'xaddons_label',
			[
				'label' => __( 'Section Label', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'We Area Creative',
				'label_block' => true,
				'condition' => [
					'xaddons_label_show' => 'yes',
				],  
			]
		);

		$this->add_control(
			'xaddons_title',
			[
				'label' => __( 'Section Title', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'Best Web Solutions',
				'label_block' => true,
				'separator' => 'before',   
			]
		);

		$this->add_control(
            'xaddons_desc_show',
            [
                'label' => __('Show Description?', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'x-addons-elementor'),
                'label_off' => __('No', 'x-addons-elementor'),
                'default' => 'yes',
				'separator' => 'before', 
            ]
        );

		$this->add_control(
			'xaddons_desc',
			[
				'label' => __( 'Section Description', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'Continually network virtual strategic theme areas',
				'condition' => [
					'xaddons_desc_show' => 'yes',
				],  
			]
		);

		$this->end_controls_section();

		// Tab #2
		$this->start_controls_section(
			'xaddons_tab_two',
			[
				'label' => __( 'Heading Styles', 'x-addons-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_responsive_control(
			'xaddons_align',
			[
				'label' => __('Alignment', 'x-addons-elementor'),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => __('Left', 'x-addons-elementor'),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => __('Center', 'x-addons-elementor'),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => __('Right', 'x-addons-elementor'),
						'icon' => 'eicon-text-align-right',
					],

				],
				'default' => 'center',
				'toggle' => false,
				'selectors' => [
                    '{{WRAPPER}} .xa-alignment' => 'justify-content: {{VALUE}}; display:flex;',
				],
			]
		);
		
		$this->add_control(
			'xaddons_text_position',
			[
				'label' => esc_html__( 'Text Position', 'x-addons-elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
                'default' => 'text-center',
				'options' => [
					'text-left' => [
                        'title' => __('Left', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'text-center' => [
                        'title' => __('Center', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'text-end' => [
                        'title' => __('Right', 'x-addons-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],
				],
                'toggle' => false,
			]
		);

		$this->end_controls_section();

	}

	function register_style_controls(){

		$this->start_controls_section(
            'xaddons_label_style',
            [
                'label' => __('Label style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'xaddons_label_show' => 'yes',
				],  
            ]
        );

		$this->add_responsive_control(
            'xaddons_label_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_label_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-section-title__label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_label_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__label' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_label_background',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__label' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_label_border',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();


		$this->start_controls_section(
            'xaddons_section_title_style',
            [
                'label' => __('Title style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_responsive_control(
            'xaddons_title_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_title_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-section-title__heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__heading' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_title_background',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__heading' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_title_border',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__heading' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
            'xaddons_section_desc_style',
            [
                'label' => __('Description style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'xaddons_desc_show' => 'yes',
				],  
            ]
        );

		$this->add_responsive_control(
            'xaddons_desc_padding',
            [
                'label' => __('Padding', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'xaddons_desc_margin',
            [
                'label' => __('Margin', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                   '{{WRAPPER}} .xa-section-title__content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_desc_color',
            [
                'label' => __('Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__content' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'xaddons_desc_background',
            [
                'label' => __('Background Color', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__content' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'xaddons_desc_border',
            [
                'label' => __('Border Radius', 'x-addons-elementor'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .xa-section-title__content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
            'xaddons_typography_style',
            [
                'label' => __('Typography style', 'x-addons-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_label_typography',
                'label' => __('Label Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-section-title__label',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_title_typography',
                'label' => __('Title Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-section-title__heading',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );

		$this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'xaddons_desc_typography',
                'label' => __('Content Typography', 'x-addons-elementor'),
                'selector' => '{{WRAPPER}} .xa-section-title__content',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
                ],
            ]
        );


		$this->end_controls_section();

	}

	/**

	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected

	 */

	 protected function render() {

        $settings = $this->get_settings_for_display();

		
        echo '
		<div class="xa-buttons xa-wrapper xa-alignment">
			<div class="xa-section-title '.esc_attr($settings['xaddons_text_position']).'">';
				if($settings['xaddons_label_show'] == true){
					echo'<span class="xa-section-title__label">'.esc_html($settings['xaddons_label']).'</span>';
				}echo'
				<h2 class="xa-section-title__heading">'.wp_kses_post($settings['xaddons_title']).'</h2>';
				if($settings['xaddons_desc_show'] == true){
					echo'<p class="xa-section-title__content">'.wp_kses_post($settings['xaddons_desc']).'</p>';
				}echo'
			</div>
		</div>';

	}

}